@@ -246,7 +246,13 @@ class CoordinateSystem(ABC):
     def slope_of_tangent(self, x: float, graph: ParametricCurve, **kwargs) -> float:
         return np.tan(self.angle_of_tangent(x, graph, **kwargs))
 
-    def get_tangent_line(self, x: float, graph: ParametricCurve, length: float = 5, line_func: Callable[[np.ndarray, np.ndarray], T] = Line) -> T:
+    def get_tangent_line(
+        self,
+        x: float,
+        graph: ParametricCurve,
+        length: float = 5,
+        line_func: Callable[[np.ndarray, np.ndarray], T] = Line,
+    ) -> T:
         line = line_func(LEFT, RIGHT)
         line.set_width(length)
         line.rotate(self.angle_of_tangent(x, graph))
