@@ -1338,7 +1338,7 @@ class Mobject(object):
         self.throw_error_if_no_points()
         return self.get_points()[-1].copy()
 
-    def get_start_and_end(self) -> tuple(np.ndarray, np.ndarray):
+    def get_start_and_end(self) -> tuple[np.ndarray, np.ndarray]:
         self.throw_error_if_no_points()
         points = self.get_points()
         return (points[0].copy(), points[-1].copy())
