@@ -7,7 +7,7 @@ import random
 import time
 from collections import OrderedDict
 from functools import wraps
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, TypeVar
 
 import numpy as np
 import pyperclip
@@ -45,6 +45,8 @@ ZOOM_KEY = "z"
 RESET_FRAME_KEY = "r"
 QUIT_KEY = "q"
 
+T = TypeVar("T", bound="Scene")
+
 
 class Scene(object):
     CONFIG = {
@@ -502,7 +504,7 @@ class Scene(object):
                 self.virtual_animation_start_time = self.time
 
             self.refresh_static_mobjects()
-            func(self, *args, **kwargs)
+            result = func(self, *args, **kwargs)
 
             if should_write:
                 self.file_writer.end_animation()
@@ -515,6 +517,7 @@ class Scene(object):
                 self.update_frame(dt=0, ignore_skipping=True)
 
             self.num_plays += 1
+            return result
 
         return wrapper
 
@@ -554,14 +557,15 @@ class Scene(object):
             self.update_mobjects(0)
 
     @handle_play_like_call
-    def play(self, *proto_animations, **animation_config) -> None:
+    def play(self, *proto_animations, **animation_config):
         if len(proto_animations) == 0:
             log.warning("Called Scene.play with no animations")
-            return
+            return self
         animations = self.prepare_animations(proto_animations, animation_config)
         self.begin_animations(animations)
         self.progress_through_animations(animations)
         self.finish_animations(animations)
+        return self
 
     @handle_play_like_call
     def wait(
